
# SpaFR
The software implementation of the method in 
[Deciphering cellular resolution functional redundancy from transcriptomic data]().

<img src="https://github.com/wangjingwan/SpaFR/blob/main/main.jpg" alt="SpaFR-Main">

# Pre-requirements
* python 3.9.2
* numpy==1.24.4, pandas==1.5.3
* seaborn==0.11.2
* matplotlib==3.8.4
* tqdm==4.67.1
from scipy.spatial import KDTree
  
# Installation
## 1. Main Package Installation (Python)
```shell
conda create --name fr_env python=3.9.23
conda activate fr_env
python -m pip install --user SpaFR
```
